import datetime
from ctypes import *

"""
公共函数 和 数据结构定义
ctypes文档参考：https://docs.python.org/zh-cn/3.10/library/ctypes.html#accessing-functions-from-loaded-dlls
"""


# write your function this file
def today():
    now = datetime.datetime.now()
    return now.strftime('%Y%m%d')


# ---------------------ctypes基础数据类型 也可以直接在excel用例中使用ctypes格式--------------------------------
def cty_char(str):
    print(c_char(str))
    return c_char(str)


def cty_wchar_p(str):
    return c_wchar_p(str)


# ---------------------传递指针（或以引用方式传递形参）--------------------------------
def cty_byref(c_type_):
    """
    构造的简单指针用于通过引用传递参数, 所以在 Python 代码本身不需要使用这个指针对象的情况下，使用 byref() 效率更高
    简单指针也可以直接在excel用例中使用ctypes格式
    :param c_type_:
    :return:
    """
    return byref(c_type_)


def cty_point(args):
    """
    构造一个真实指针对象
    复杂的指针在此定义
    :return:
    """
    class POINT(Structure):
        _fields_ = [("x", c_int), ("y", c_int)]

    point = POINT(10, 20)
    print(point.x, point.y)
    return point


# 获取告警规则用例
class AlarmRule(Structure):
    """数据结构定义-获取单个直接调用传值"""
    _fields_ = [
        ("id", c_char * 128),
        ("tag", c_char * 128),
        ("relativetags", c_char * 512),
        ("desc", c_char * 128),
        ("area", c_char * 64),
        ("deadband", c_double),
        ("value", c_double),
        ("interval", c_ushort),
        ("enable", c_ubyte),
        ("autoAck", c_ubyte),
        ("condition", c_ubyte),
        ("deadbandType", c_ubyte),
        ("severity", c_ubyte),
        ("comparison", c_ubyte),
    ]


def alms_array(id1, id2, id3, id4):
    """获取多个告警规则用例 数据结构传值"""
    alms = [
        AlarmRule(id1, b'', b'', b'', b'', 0, 0, 0, 0, 0, 0, 0, 0),
        AlarmRule(id2, b'', b'', b'', b'', 0, 0, 0, 0, 0, 0, 0, 0),
        AlarmRule(id3, b'', b'', b'', b'', 0, 0, 0, 0, 0, 0, 0, 0),
        AlarmRule(id4, b'', b'', b'', b'', 0, 0, 0, 0, 0, 0, 0, 0),
    ]

    alms_array_ = (AlarmRule * len(alms))(*alms)
    return alms_array_
